@@ -2,7 +2,7 @@ require 'stringio'
 require 'timeout'
 require "./run.rb"
 
-special_things = %w'@ $ ! > , [ ] = : ; f F m M i I e E nil if nuke stdin superpad version type pp show  1,2,3 0,0 1,2,,3,4 "asdf" "" 1000'
+special_things = %w'@ $ ! > , [ ] ~ : ; f F m M i I e E nil if nuke stdin superpad version type pp show  1,2,3 0,0 1,2,,3,4 "asdf" "" 1000'
 
 all = ["\n",*' '..'~'] + special_things*3 + [" "]*2
 
@@ -13,8 +13,8 @@ ReadStdin = Promise.new{ str_to_lazy_list("ab12") }
 
 n = 100000
 
-4.upto(8){|program_size|
-  ([all.size**program_size*2*3+100,n].min).times{|i|
+1.upto(8){|program_size|
+  ([all.size**program_size*2+100,n].min).times{|i|
     program = program_size.times.map{ all.sample }*""
     $stdout = StringIO.new("")
     begin
